@@ -3,10 +3,9 @@ import pygame as pg
 
 from PyGine.Camera import Camera
 from PyGine.Component import Component
-import PyGine.PyGineGame as Game
+import PyGine.PyGinegame as Game
 from PyGine.Transform import Transform
 
-
 class BoxColliderComponent(Component) :
     def __init__(self,parent) :
         super().__init__(parent)
